pygeodesy.unitsBase.Float

Package pygeodesy :: Module unitsBase :: Class Float |
[frames] | no frames]

# Class Float

          object --+
                   |
               float --+
                       |
      object --+       |
               |       |
    named._Named --+   |
                   |   |
          _NamedUnit --+
                       |
                      Float

Known Subclasses:
  - units.Radians
  - , units.Degrees
  - , units.Degrees2
  - , units.Distance
  - , units.Float_
  - , units._EasNorBase
  - , units.Feet
  - , units.Height
  - , units.Meter
  - , Radius
  - , units.Scalar
  - , deprecated.consterns._Deprecated_Float

Named `float`.

Instance Methods
__repr__(self) Return a representation of this `Float`. |
__str__(self) Return this `Float` as standard `str`. |
toRepr(self, std=False, **prec_fmt_ints) Return a representation of this `Float`. |
toStr(self, prec=12, fmt='g', ints=False) Format this `Float` as `str`. |
Inherited from `float`: `__abs__`, `__add__`, `__coerce__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floordiv__`, `__format__`, `__ge__`, `__getattribute__`, `__getformat__`, `__getnewargs__`, `__gt__`, `__hash__`, `__int__`, `__le__`, `__long__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmod__`, `__rmul__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__setformat__`, `__sub__`, `__truediv__`, `__trunc__`, `as_integer_ratio`, `conjugate`, `fromhex`, `hex`, `is_integer` Inherited from `named._Named`: `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, arg=None, name='', **Error_name_arg) New, named `Ffloat`. |

Properties
Inherited from `float`: `imag`, `real` Inherited from `_NamedUnit`: `std_repr`, `units` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, arg=None, name='', **Error_name_arg) Static Method |
New, named `Ffloat`. Arguments: `arg` - The value (any `type` acceptable to `float`). `name` - Optional name (`str`). `Error_name_arg` - Optional `Error=UnitError` to raise and optional `name=arg` keyword argument, inlieu of separate `arg` and `name` ones. Returns: a new object with type S, a subtype of T A named `Float`. Raises: `Error` - Invalid `arg`. Overrides: object.__new__

### __repr__ (self) (Representation operator) |
Return a representation of this `Float`. Overrides: object.__repr__ See Also: Method `Float.toRepr` and property `Float.std_repr`. Note: Use `env` variable `PYGEODESY_FLOAT_STD_REPR=std` prior to `import pygeodesy` to get the standard `repr` or set property `std_repr=False` to always get the named `toRepr` representation.

### __str__ (self) (Informal representation operator) |
Return this `Float` as standard `str`. Overrides: object.__str__

### toRepr (self, std=False, **prec_fmt_ints) |
Return a representation of this `Float`. Arguments: `std` - If `True`, return the standard `repr`, otherwise the named representation (`bool`). Overrides: named._Named.toRepr See Also: Function fstr and methods Float.__repr__, Float.toStr for further details.

### toStr (self, prec=12, fmt='g', ints=False) |
Format this `Float` as `str`. Overrides: named._Named.toStr See Also: Function fstr and method Float.__repr__ and for further information.